@@ -12,7 +12,7 @@
 ##############################################################################
 """ MaildropHost is a transaction-aware asynchronous MailHost for Zope 2
 
-$Id: MaildropHost.py 1794 2009-05-29 08:22:29Z jens $
+$Id: MaildropHost.py 1815 2009-10-09 21:14:55Z jens $
 """
 
 # General python imports
@@ -130,7 +130,13 @@ class MaildropHost(MailHost):
         # Persist the new path, and then reload the configuration
         self.config_path = CONFIG_PATHS.get(path_key)
         self._load_config()
-        
+
+    security.declareProtected(change_configuration, 'addConfigPath')
+    def addConfigPath(self, path_key, path):
+        """ Method to add a config path programmatically
+        """
+        CONFIG_PATHS[path_key] = path
+
     security.declareProtected(change_configuration, 'getCandidateConfigPaths')
     def getCandidateConfigPaths(self):
         """ Retrieve the config paths set in zope.conf
