@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) Jens Vagelpohl and Contributors. All Rights Reserved.
+# Copyright (c) 2004-2009 Jens Vagelpohl and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -12,13 +12,13 @@
 ##############################################################################
 """ MaildropHost initialization
 
-$Id: __init__.py 1648 2008-10-31 18:22:44Z jens $
+$Id: __init__.py 1696 2009-02-08 08:22:06Z jens $
 """
 
 from AccessControl.Permissions import add_mailhost_objects
-from MaildropHost import addMaildropHostForm
-from MaildropHost import MaildropHost
-from MaildropHost import manage_addMaildropHost
+from Products.MaildropHost.MaildropHost import addMaildropHostForm
+from Products.MaildropHost.MaildropHost import MaildropHost
+from Products.MaildropHost.MaildropHost import manage_addMaildropHost
 
 def initialize( context ):
     try:
