@@ -12,7 +12,7 @@
 ##############################################################################
 """ MaildropHost tests
 
-$Id: test_MaildropHost.py 1794 2009-05-29 08:22:29Z jens $
+$Id: test_MaildropHost.py 1815 2009-10-09 21:14:55Z jens $
 """
 
 import os
@@ -173,6 +173,23 @@ class MaildropHostTests(unittest.TestCase):
         # cleanup
         CONFIG_PATHS = old_config_paths
 
+    def testAddConfigPathMethod(self):
+        from Products.MaildropHost.MaildropHost import CONFIG_PATHS
+        old_config_paths = CONFIG_PATHS.copy()
+        mdh = self._makeOne('MDH', 'MDH Title')
+        candidates = mdh.getCandidateConfigPaths()
+        # config paths may have been added elsewhere
+        num_current_paths = len(candidates)
+        config_path = '/a/system/path'
+        mdh.addConfigPath('program_path', config_path)
+        candidates = mdh.getCandidateConfigPaths()
+        self.assertEquals(len(candidates), num_current_paths + 1)
+        self.failUnless('program_path' in [x[0] for x in candidates])
+        self.assertEquals(CONFIG_PATHS['program_path'], config_path)
+
+        # cleanup
+        CONFIG_PATHS = old_config_paths
+
 
 def test_suite():
     return unittest.TestSuite((
